==> pui-css-media-5.1.3.tgz: package/README.md <==
# pui-css-media

A CSS media component that can be installed via this npm package.
This package provides all of the CSS you need to use the component.



## Installation

To install the package from the command line:

```
npm install pui-css-media
```

## Usage

```html
<div class="media">
  <a class="media-left" href="#">
    <img alt="placeholder" class="media-object" src="http://placehold.it/64x64"/>
  </a>
  <div class="media-body">
    <h4 class="media-heading">Media heading</h4>
    Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin commodo. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.
  </div>
</div>

<div class="media">
  <div class="media-body">
    <h4 class="media-heading">Media heading</h4>
    Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin commodo. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis.
  </div>
  <a class="media-right" href="#">
    <img alt="placeholder" class="media-object" src="http://placehold.it/64x64"/>
  </a>
</div>
```


You can find more examples of the media component in the [pui style guide](http://styleguide.pivotal.io/)


*****************************************

This is a component of Pivotal UI, a collection of [React](https://facebook.github.io/react/) and CSS components for rapidly building and prototyping UIs.

[Styleguide](http://styleguide.pivotal.io)
[Github](https://github.com/pivotal-cf/pivotal-ui)
[npm](https://www.npmjs.com/browse/keyword/pivotal%20ui%20modularized)

(c) Copyright 2016 Pivotal Software, Inc. All Rights Reserved.

==> pui-css-media-6.2.1.tgz: package/README.md <==
# @npmcorp/pui-css-media

A CSS media component that can be installed via this npm package. The package provides all of the
CSS you need to use the component.



## Installation

To install the package, from the command line, type:

```
npm install pui-css-media
```

## Usage

```html
<div class="media">
  <a class="media-left" href="#">
    <img alt="placeholder" class="media-object" src="http://placehold.it/64x64"/>
  </a>
  <div class="media-body">
    <h4 class="media-heading">Media heading</h4>
    Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin commodo. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis. Fusce condimentum nunc ac nisi vulputate fringilla. Donec lacinia congue felis in faucibus.
  </div>
</div>

<div class="media">
  <div class="media-body">
    <h4 class="media-heading">Media heading</h4>
    Cras sit amet nibh libero, in gravida nulla. Nulla vel metus scelerisque ante sollicitudin commodo. Cras purus odio, vestibulum in vulputate at, tempus viverra turpis.
  </div>
  <a class="media-right" href="#">
    <img alt="placeholder" class="media-object" src="http://placehold.it/64x64"/>
  </a>
</div>
```


You can find more examples of the media component in the [pui style guide](http://styleguide.pivotal.io/section.html#media)

*****************************************

This is a component of Pivotal UI. It is a Pivotal specific implementation of Bootstrap.

[Styleguide](http://styleguide.pivotal.io)
[Github](https://github.com/pivotal-cf/pivotal-ui)

(c) Copyright 2015 Pivotal Software, Inc. All Rights Reserved.
